# pvenv: Easy python virtual environment management

[![tests][test_badge]][test_url]
[![license][licence_badge]][licence_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![code style: black][black_badge]][black_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`pvenv` provides an easy way to use venvs in python.

## Links

-   [Documentation]
-   [Changelog]

[test_badge]: https://github.com/spapanik/pvenv/actions/workflows/tests.yml/badge.svg
[test_url]: https://github.com/spapanik/pvenv/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/pypi/l/pvenv
[licence_url]: https://github.com/spapanik/pvenv/blob/main/docs/LICENSE.md
[pypi_badge]: https://img.shields.io/pypi/v/pvenv
[pypi_url]: https://pypi.org/project/pvenv
[pepy_badge]: https://pepy.tech/badge/pvenv
[pepy_url]: https://pepy.tech/project/pvenv
[black_badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black_url]: https://github.com/psf/black
[yam_badge]: https://img.shields.io/badge/build%20automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://p-venv.readthedocs.io/en/stable/
[Changelog]: https://github.com/spapanik/pvenv/blob/main/docs/CHANGELOG.md
